import React, { useEffect, Suspense, lazy } from 'react'
import ReactDOM from 'react-dom/client'
import { BrowserRouter, Routes, Route, useLocation } from 'react-router-dom'
import { HelmetProvider } from 'react-helmet-async'
import App from './App.jsx'
import './index.css'

// Lazy load components for code splitting
const HistoryPage = lazy(() => import('./HistoryPage.jsx'))
const Privacy = lazy(() => import('./pages/Privacy.jsx'))
const Terms = lazy(() => import('./pages/Terms.jsx'))
const FAQ = lazy(() => import('./pages/FAQ.jsx'))
const Testimonials = lazy(() => import('./pages/Testimonials.jsx'))
const Contact = lazy(() => import('./pages/Contact.jsx'))
const NotFound = lazy(() => import('./pages/NotFound.jsx'))
const Guide = lazy(() => import('./pages/Guide.jsx'))
const GuideFindingYourNiche = lazy(() => import('./pages/GuideFindingYourNiche.jsx'))
const NicheFitness = lazy(() => import('./pages/niche/Fitness.jsx'))
const NicheCooking = lazy(() => import('./pages/niche/Cooking.jsx'))
const NicheBeautyMakeup = lazy(() => import('./pages/niche/BeautyMakeup.jsx'))
const NicheSmallBusiness = lazy(() => import('./pages/niche/SmallBusiness.jsx'))
const NicheEducation = lazy(() => import('./pages/niche/Education.jsx'))
const GuideTrendingFormats = lazy(() => import('./pages/GuideTrendingFormats.jsx'))
const GuideHooks = lazy(() => import('./pages/GuideHooks.jsx'))
const GuideCTAs = lazy(() => import('./pages/GuideCTAs.jsx'))
const GuideBatchFilming = lazy(() => import('./pages/GuideBatchFilming.jsx'))
const Sitemap = lazy(() => import('./pages/Sitemap.jsx'))
const TikTokShop = lazy(() => import('./pages/niche/TikTokShop.jsx'))
const GuideTikTokShopMarketing = lazy(() => import('./pages/GuideTikTokShopMarketing.jsx'))
const Niche = lazy(() => import('./pages/niche/Niche'))
const Blog = lazy(() => import('./pages/Blog.jsx'))
const BlogPost = lazy(() => import('./pages/BlogPost.jsx'))

function AnalyticsListener() {
  const location = useLocation();
  useEffect(() => {
    if (import.meta.env.PROD && window.gtag) {
      window.gtag('event', 'page_view', {
        page_path: location.pathname + location.search,
      });
    }
  }, [location]);
  return null;
}

// Dynamically load GA4 analytics in production
function AnalyticsLoader() {
  useEffect(() => {
    if (import.meta.env.PROD && import.meta.env.VITE_GA_ID) {
      const ga = document.createElement('script');
      ga.src = `https://www.googletagmanager.com/gtag/js?id=${import.meta.env.VITE_GA_ID}`;
      ga.async = true;
      document.head.appendChild(ga);
      window.dataLayer = window.dataLayer || [];
      function gtag(){window.dataLayer.push(arguments);}
      gtag('js', new Date());
      gtag('config', import.meta.env.VITE_GA_ID, { anonymize_ip: true });
    }

  }, []);
  return null;
}

ReactDOM.createRoot(document.getElementById('root')).render(
  <React.StrictMode>
    <HelmetProvider>
      <BrowserRouter>
        <AnalyticsLoader />
        <AnalyticsListener />
        <Suspense fallback={
          <div className="min-h-screen bg-gradient-to-br from-blue-50 via-white to-blue-50 flex items-center justify-center">
            <div className="text-center">
              <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-blue-600 mx-auto mb-4"></div>
              <p className="text-blue-800 font-medium">Loading...</p>
            </div>
          </div>
        }>
          <Routes>
            <Route path="/" element={<App />} />
            <Route path="/history" element={<HistoryPage />} />
            <Route path="/privacy" element={<Privacy />} />
            <Route path="/terms" element={<Terms />} />
            <Route path="/faq" element={<FAQ />} />
            <Route path="/testimonials" element={<Testimonials />} />
            <Route path="/contact" element={<Contact />} />
            <Route path="/guide" element={<Guide />} />
            <Route path="/guide/finding-your-niche" element={<GuideFindingYourNiche />} />
            <Route path="/guide/trending-formats" element={<GuideTrendingFormats />} />
            <Route path="/guide/hooks" element={<GuideHooks />} />
            <Route path="/guide/ctas" element={<GuideCTAs />} />
            <Route path="/guide/batch-filming" element={<GuideBatchFilming />} />
            <Route path="/guide/tiktok-shop-marketing" element={<GuideTikTokShopMarketing />} />
            <Route path="/niche/fitness" element={<NicheFitness />} />
            <Route path="/niche/cooking" element={<NicheCooking />} />
            <Route path="/niche/beauty-makeup" element={<NicheBeautyMakeup />} />
            <Route path="/niche/small-business" element={<NicheSmallBusiness />} />
            <Route path="/niche/education" element={<NicheEducation />} />
            <Route path="/niche/tiktokshop" element={<TikTokShop />} />
            <Route path="/niche" element={<Niche />} />
            <Route path="/sitemap" element={<Sitemap />} />
            <Route path="/blog" element={<Blog />} />
            <Route path="/blog/:postId" element={<BlogPost />} />
            <Route path="*" element={<NotFound />} />
          </Routes>
        </Suspense>
      </BrowserRouter>
    </HelmetProvider>
  </React.StrictMode>,
) 